# Topsis Module
Implementation of MCDM using topsis in python

## Installation
```pip install Topsis-Lakshit-102017054```

## How to use it?
Open terminal and type topsis followed by dataset weights impacts and resulting dataset name

## License

Ⓒ 2023 Lakshit Patidar

This repository is licensed under the MIT license.
See LICENSE for details
